@@ -150,6 +150,9 @@ class Git(object):
                 """Return the name of this section."""
                 return self._name
 
+            def __iter__(self):
+                yield from self._items.items()
+
             def itemname(self, key):
                 """Return the full name of a key, including the section."""
                 return self.name + '.' + key
@@ -576,6 +579,12 @@ class Git(object):
         branch_name = self.refname_to_branch_name(branch_name)
         self._repo.branches.create(branch_name, commit)
 
+    def get_current_branch(self):
+        """Get the currently-checked-out branch."""
+        if self.head_is_detached():
+            return None
+        return self.refname_to_branch_name(self.get_current_refname())
+
     def set_branch_upstream(self, branch_name, remote_branch_name):
         """Set the upstream of branch_name to remote_branch_name."""
         branch_name = self.refname_to_branch_name(branch_name)
@@ -591,6 +600,7 @@ class Git(object):
         branch.upstream = remote_branch
 
     def get_branch_upstream(self, branch_name):
+        """Get the upstream branch of the given local branch."""
         branch_name = self.refname_to_branch_name(branch_name)
         branch = self._repo.branches[branch_name]
         result = None
